"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Dispatcher = void 0;
const constants_1 = require("../constants");
const AriesFrameworkError_1 = require("../error/AriesFrameworkError");
const plugins_1 = require("../plugins");
const messageType_1 = require("../utils/messageType");
const ProblemReportMessage_1 = require("./../modules/problem-reports/messages/ProblemReportMessage");
const EventEmitter_1 = require("./EventEmitter");
const Events_1 = require("./Events");
const MessageSender_1 = require("./MessageSender");
const models_1 = require("./models");
let Dispatcher = class Dispatcher {
    constructor(messageSender, eventEmitter, logger) {
        this.handlers = [];
        this.messageSender = messageSender;
        this.eventEmitter = eventEmitter;
        this.logger = logger;
    }
    registerHandler(handler) {
        this.handlers.push(handler);
    }
    async dispatch(messageContext) {
        const { agentContext, connection, senderKey, recipientKey, message } = messageContext;
        const handler = this.getHandlerForType(message.type);
        if (!handler) {
            throw new AriesFrameworkError_1.AriesFrameworkError(`No handler for message type "${message.type}" found`);
        }
        let outboundMessage;
        try {
            outboundMessage = await handler.handle(messageContext);
        }
        catch (error) {
            const problemReportMessage = error.problemReport;
            if (problemReportMessage instanceof ProblemReportMessage_1.ProblemReportMessage && messageContext.connection) {
                problemReportMessage.setThread({
                    threadId: message.threadId,
                });
                outboundMessage = new models_1.OutboundMessageContext(problemReportMessage, {
                    agentContext,
                    connection: messageContext.connection,
                });
            }
            else {
                this.logger.error(`Error handling message with type ${message.type}`, {
                    message: message.toJSON(),
                    error,
                    senderKey: senderKey === null || senderKey === void 0 ? void 0 : senderKey.fingerprint,
                    recipientKey: recipientKey === null || recipientKey === void 0 ? void 0 : recipientKey.fingerprint,
                    connectionId: connection === null || connection === void 0 ? void 0 : connection.id,
                });
                throw error;
            }
        }
        if (outboundMessage) {
            if (outboundMessage.isOutboundServiceMessage()) {
                await this.messageSender.sendMessageToService(outboundMessage);
            }
            else {
                outboundMessage.sessionId = messageContext.sessionId;
                await this.messageSender.sendMessage(outboundMessage);
            }
        }
        // Emit event that allows to hook into received messages
        this.eventEmitter.emit(agentContext, {
            type: Events_1.AgentEventTypes.AgentMessageProcessed,
            payload: {
                message,
                connection,
            },
        });
    }
    getHandlerForType(messageType) {
        const incomingMessageType = messageType_1.parseMessageType(messageType);
        for (const handler of this.handlers) {
            for (const MessageClass of handler.supportedMessages) {
                if (messageType_1.canHandleMessageType(MessageClass, incomingMessageType))
                    return handler;
            }
        }
    }
    getMessageClassForType(messageType) {
        const incomingMessageType = messageType_1.parseMessageType(messageType);
        for (const handler of this.handlers) {
            for (const MessageClass of handler.supportedMessages) {
                if (messageType_1.canHandleMessageType(MessageClass, incomingMessageType))
                    return MessageClass;
            }
        }
    }
    /**
     * Returns array of message types that dispatcher is able to handle.
     * Message type format is MTURI specified at https://github.com/hyperledger/aries-rfcs/blob/main/concepts/0003-protocols/README.md#mturi.
     */
    get supportedMessageTypes() {
        return this.handlers
            .reduce((all, cur) => [...all, ...cur.supportedMessages], [])
            .map((m) => m.type);
    }
    /**
     * Returns array of protocol IDs that dispatcher is able to handle.
     * Protocol ID format is PIURI specified at https://github.com/hyperledger/aries-rfcs/blob/main/concepts/0003-protocols/README.md#piuri.
     */
    get supportedProtocols() {
        return Array.from(new Set(this.supportedMessageTypes.map((m) => m.protocolUri)));
    }
    filterSupportedProtocolsByMessageFamilies(messageFamilies) {
        return this.supportedProtocols.filter((protocolId) => messageFamilies.find((messageFamily) => protocolId.startsWith(messageFamily)));
    }
};
Dispatcher = __decorate([
    plugins_1.injectable(),
    __param(2, plugins_1.inject(constants_1.InjectionSymbols.Logger)),
    __metadata("design:paramtypes", [MessageSender_1.MessageSender,
        EventEmitter_1.EventEmitter, Object])
], Dispatcher);
exports.Dispatcher = Dispatcher;
//# sourceMappingURL=Dispatcher.js.map