import type { AgentContext } from '../../../../agent';
import type { Attachment } from '../../../../decorators/attachment/Attachment';
import type { FormatAcceptOfferOptions, FormatAcceptProposalOptions, FormatAcceptRequestOptions, FormatAutoRespondCredentialOptions, FormatAutoRespondOfferOptions, FormatAutoRespondProposalOptions, FormatAutoRespondRequestOptions, FormatCreateOfferOptions, FormatCreateOfferReturn, FormatCreateProposalOptions, FormatCreateProposalReturn, CredentialFormatCreateReturn, FormatProcessOptions } from '../CredentialFormatServiceOptions';
import type { IndyCredentialFormat } from './IndyCredentialFormat';
import { Logger } from '../../../../logger';
import { ConnectionService } from '../../../connections';
import { DidResolverService } from '../../../dids';
import { IndyHolderService, IndyIssuerService } from '../../../indy';
import { IndyLedgerService } from '../../../ledger';
import { CredentialFormatSpec } from '../../models/CredentialFormatSpec';
import { CredentialFormatService } from '../CredentialFormatService';
export declare class IndyCredentialFormatService extends CredentialFormatService<IndyCredentialFormat> {
    private indyIssuerService;
    private indyLedgerService;
    private indyHolderService;
    private connectionService;
    private didResolver;
    private logger;
    constructor(indyIssuerService: IndyIssuerService, indyLedgerService: IndyLedgerService, indyHolderService: IndyHolderService, connectionService: ConnectionService, didResolver: DidResolverService, logger: Logger);
    readonly formatKey: "indy";
    readonly credentialRecordType: "indy";
    /**
     * Create a {@link AttachmentFormats} object dependent on the message type.
     *
     * @param options The object containing all the options for the proposed credential
     * @returns object containing associated attachment, format and optionally the credential preview
     *
     */
    createProposal(agentContext: AgentContext, { credentialFormats, credentialRecord }: FormatCreateProposalOptions<IndyCredentialFormat>): Promise<FormatCreateProposalReturn>;
    processProposal(agentContext: AgentContext, { attachment }: FormatProcessOptions): Promise<void>;
    acceptProposal(agentContext: AgentContext, { attachId, credentialFormats, credentialRecord, proposalAttachment, }: FormatAcceptProposalOptions<IndyCredentialFormat>): Promise<FormatCreateOfferReturn>;
    /**
     * Create a credential attachment format for a credential request.
     *
     * @param options The object containing all the options for the credential offer
     * @returns object containing associated attachment, formats and offersAttach elements
     *
     */
    createOffer(agentContext: AgentContext, { credentialFormats, credentialRecord, attachId }: FormatCreateOfferOptions<IndyCredentialFormat>): Promise<FormatCreateOfferReturn>;
    processOffer(agentContext: AgentContext, { attachment, credentialRecord }: FormatProcessOptions): Promise<void>;
    acceptOffer(agentContext: AgentContext, { credentialFormats, credentialRecord, attachId, offerAttachment }: FormatAcceptOfferOptions<IndyCredentialFormat>): Promise<CredentialFormatCreateReturn>;
    /**
     * Starting from a request is not supported for indy credentials, this method only throws an error.
     */
    createRequest(): Promise<CredentialFormatCreateReturn>;
    /**
     * We don't have any models to validate an indy request object, for now this method does nothing
     */
    processRequest(agentContext: AgentContext, options: FormatProcessOptions): Promise<void>;
    acceptRequest(agentContext: AgentContext, { credentialRecord, attachId, offerAttachment, requestAttachment }: FormatAcceptRequestOptions<IndyCredentialFormat>): Promise<CredentialFormatCreateReturn>;
    /**
     * Processes an incoming credential - retrieve metadata, retrieve payload and store it in the Indy wallet
     * @param options the issue credential message wrapped inside this object
     * @param credentialRecord the credential exchange record for this credential
     */
    processCredential(agentContext: AgentContext, { credentialRecord, attachment }: FormatProcessOptions): Promise<void>;
    supportsFormat(format: string): boolean;
    /**
     * Gets the attachment object for a given attachId. We need to get out the correct attachId for
     * indy and then find the corresponding attachment (if there is one)
     * @param formats the formats object containing the attachId
     * @param messageAttachments the attachments containing the payload
     * @returns The Attachment if found or undefined
     *
     */
    getAttachment(formats: CredentialFormatSpec[], messageAttachments: Attachment[]): Attachment | undefined;
    deleteCredentialById(agentContext: AgentContext, credentialRecordId: string): Promise<void>;
    shouldAutoRespondToProposal(agentContext: AgentContext, { offerAttachment, proposalAttachment }: FormatAutoRespondProposalOptions): boolean;
    shouldAutoRespondToOffer(agentContext: AgentContext, { offerAttachment, proposalAttachment }: FormatAutoRespondOfferOptions): boolean;
    shouldAutoRespondToRequest(agentContext: AgentContext, { offerAttachment, requestAttachment }: FormatAutoRespondRequestOptions): boolean;
    shouldAutoRespondToCredential(agentContext: AgentContext, { credentialRecord, requestAttachment, credentialAttachment }: FormatAutoRespondCredentialOptions): boolean;
    private createIndyOffer;
    private assertPreviewAttributesMatchSchemaAttributes;
    private getIndyHolderDid;
    /**
     * Get linked attachments for indy format from a proposal message. This allows attachments
     * to be copied across to old style credential records
     *
     * @param options ProposeCredentialOptions object containing (optionally) the linked attachments
     * @return array of linked attachments or undefined if none present
     */
    private getCredentialLinkedAttachments;
}
